aboutsummaryrefslogtreecommitdiffstats
path: root/docbook/dfilter2xml.pl
diff options
context:
space:
mode:
authorBill Meier <wmeier@newsguy.com>2007-01-02 17:19:25 +0000
committerBill Meier <wmeier@newsguy.com>2007-01-02 17:19:25 +0000
commit444602bf9799d9912495b472943239db53fd43e8 (patch)
treeeb728b49cee42d167242d5e97e7586b06e695d17 /docbook/dfilter2xml.pl
parentd9da45e31eb47336c44df8e8e4791f7e81ff79df (diff)
Oops: wireshark.com --> wireshark.org
Also: 1 additional Ethereal --> Wireshark svn path=/trunk/; revision=20272
Diffstat (limited to 'docbook/dfilter2xml.pl')
-rw-r--r--docbook/dfilter2xml.pl6
1 files changed, 3 insertions, 3 deletions
diff --git a/docbook/dfilter2xml.pl b/docbook/dfilter2xml.pl
index a2e6971215..ef1b4b4e1d 100644
--- a/docbook/dfilter2xml.pl
+++ b/docbook/dfilter2xml.pl
@@ -1,10 +1,10 @@
#!/usr/bin/perl
#
-# Reads the display filter keyword dump produced by 'ethereal -G' and
+# Reads the display filter keyword dump produced by 'tshark -G' and
# formats it for a pod document. The pod document is then used to
# make a manpage
#
# STDIN is the ethereal glossary
# arg1 is the pod template file. The =insert_dfilter_table token
# will be replaced by the pod-formatted glossary
# STDOUT is the output
@@ -84,7 +84,7 @@ close(TEMPLATE) || die "Can't close $template: $!\n";
sub create_dfilter_table {
- print "<appendix id=\"AppFiltFields\"><title>Ethereal Display Filter Fields</title>\n";
+ print "<appendix id=\"AppFiltFields\"><title>Wireshark Display Filter Fields</title>\n";
$pn_counter = 1;
# Print each protocol
@@ -1,10 +1,10 @@
# make a manpage
#
-# STDIN is the ethereal glossary
+# STDIN is the wireshark glossary
# arg1 is the pod template file. The =insert_dfilter_table token
# will be replaced by the pod-formatted glossary